@@ -29,7 +29,7 @@ void	SetCurrentProfile(const string &s);
 string	GetCurrentProfile();
 
 void	NeedSecureUserConfig();
-void	LoadAllConfig(int quiet);
+void	LoadAllConfig(bool quiet);
 void	PrintConfig();
 void	PrintAttrConfig();
 
