@@ -1,6 +1,6 @@
 /*
 	dirutil.cc	Directory Utility Functions
-	Copyright (c) 2000,2001 Kriang Lerdsuwanakij
+	Copyright (c) 2000,2001,2003 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@
 
 
 						// Expand ~ to full dir. path
-string	ExpandDirectory(const string &src, int quote)
+string	ExpandDirectory(const string &src, bool quote)
 {
 	string	outStr;
 	if (!src.size())			// String empty
@@ -70,20 +70,34 @@ string	ExpandDirectory(const string &src, int quote)
 			if (quote)
 				outStr = QuoteGlobChars(outStr);
 
-					// Remaining doesn't quoting since we
-					// allow globing in SkipDir
-			outStr.append(src, 1, string::npos);
+					// We allow globing in SkipDir
+			string	temp(src, 1, string::npos);
+			if (quote) {
+				try {
+					temp = UnquoteShellChars(temp, true);
+				}
+				catch (ErrorRange &) {
+					throw ErrorGenericSyntax(_("bad quoting for"
+								   " directory `%$\'"),
+								 temp);
+				}
+			}
+			outStr.append(temp);
 		}
-		else {
+		else {			// ~user
+
 			string::size_type	s = src.find('/');
 			if (s == string::npos) {
 					// Skip the `~'
-				string	temp(src, 1);
+				string	temp(src, 1, string::npos);
 				if (quote) {
 					try {
-						temp = UnquoteShellChars(temp);
+						temp = UnquoteShellChars(temp, true);
 					}
-					catch (ErrorRange &) {	// Ignore
+					catch (ErrorRange &) {
+						throw ErrorGenericSyntax(_("bad quoting for"
+									   " directory `%$\'"),
+									 temp);
 					}
 				}
 
@@ -101,9 +115,12 @@ string	ExpandDirectory(const string &src, int quote)
 				string	temp(src, 1, s-1);
 				if (quote) {
 					try {
-						temp = UnquoteShellChars(temp);
+						temp = UnquoteShellChars(temp, true);
 					}
-					catch (ErrorRange &) {	// Ignore
+					catch (ErrorRange &) {
+						throw ErrorGenericSyntax(_("bad quoting for"
+									   " directory `%$\'"),
+									 temp);
 					}
 				}
 
@@ -123,14 +140,38 @@ string	ExpandDirectory(const string &src, int quote)
 				outStr = QuoteGlobChars(outStr);
 
 					// Append remaining of directory name.
-					// Remaining doesn't quoting since we
-					// allow globing in SkipDir
-			if (s != string::npos)
+			if (s != string::npos) {
 				outStr.append(src, s+1, string::npos);
+					// We allow globing in SkipDir
+				string	temp(src, s+1, string::npos);
+				if (quote) {
+					try {
+						temp = UnquoteShellChars(temp, true);
+					}
+					catch (ErrorRange &) {
+						throw ErrorGenericSyntax(_("bad quoting for"
+									   " directory `%$\'"),
+									 temp);
+					}
+				}
+				outStr.append(temp);
+			}
 		}
 	}
-	else
-		outStr = src;
+	else {
+		if (quote) {
+			try {
+				outStr = UnquoteShellChars(src, true);
+			}
+			catch (ErrorRange &) {
+				throw ErrorGenericSyntax(_("bad quoting for"
+							   " directory `%$\'"),
+							 src);
+			}
+		}
+		else
+			outStr = src;
+	}
 
 	if (outStr[0] != '/' && outStr[0] != '*' && outStr[0] != '?' 
 	    && outStr[0] != '[' && outStr[0] != '\\') {
