@@ -27,6 +27,7 @@
 #include "dirtree.h"
 #include "dirutil.h"
 #include "cstrlib.h"
+#include "scandir.h"
 
 //#define DUMP_HTML	
 #ifdef DUMP_HTML
@@ -99,6 +100,8 @@ void	ReplaceControlChar(string &s)
 
 class HyperTreeDraw : public HyperDraw {
 	private:
+		sptr_list<DirectoryEntry> *dirTree;
+
 		vector<size_t>	barStack;	// Positions of vertical bars
 		size_t	curCol;			// curRow not needed
 
@@ -115,8 +118,12 @@ class HyperTreeDraw : public HyperDraw {
 		void	RecursiveGenerateHTML(HyperDocument &html, WINDOW *pad,
 					      sptr<DirectoryEntry> &d, 
 					      size_t pos, const string &current_dir);
+		void	DrawBegin(HyperDocument &html, WINDOW *pad);
+		void	DrawEnd(HyperDocument &html, WINDOW *pad);
 	public:
 		void	Draw(HyperDocument &html, WINDOW *pad);
+		HyperTreeDraw(sptr_list<DirectoryEntry> *dirTree_)
+				: dirTree(dirTree_) {}
 };
 
 void	HyperTreeDraw::NewLineUpdateRowCol()
@@ -152,7 +159,7 @@ void	HyperTreeDraw::GenerateSymLinkHTML(HyperDocument &html, WINDOW *pad,
 						// Write tags
 		html.DrawAName(pad, new_dir);
 
-		html.DrawACallBegin(pad, new_dir);
+		html.DrawACallBegin(pad, d->GetLinkDestStr());
 
 		html.DrawSetItalic(pad);
 
@@ -342,7 +349,7 @@ void	HyperTreeDraw::RecursiveGenerateHTML(HyperDocument &html, WINDOW *pad,
 	}
 }
 
-void	HyperTreeDraw::Draw(HyperDocument &html, WINDOW *pad)
+void	HyperTreeDraw::DrawBegin(HyperDocument &html, WINDOW *pad)
 {
 	htmlRow = 0;
 	htmlCol = 0;
@@ -364,10 +371,34 @@ void	HyperTreeDraw::Draw(HyperDocument &html, WINDOW *pad)
 		html.DrawSetTitle(bufstr.str());
 	}
 
+}
+
+void	HyperTreeDraw::DrawEnd(HyperDocument &html, WINDOW *pad)
+{
+	if (curCol != 0) {		// Not end with new line
+		html.DrawChar(pad, '\n');
+		NewLineUpdateRowCol();	// One more line needed
+	}
+
+	if (! pad) {
+//ofstream ofs("xx", ios::app);
+//if (!pad)
+//ofs << htmlRow << ' ' << htmlCol << ' ' << '\n';
+		html.DrawSetSize(htmlRow, htmlCol);
+	}
+	else {
+		;			// Nothing to do
+	}
+}
+
+void	HyperTreeDraw::Draw(HyperDocument &html, WINDOW *pad)
+{
+	DrawBegin(html, pad);
+
 	bool	first = true;
 
-	for (sptr_list<DirectoryEntry>::iterator iter = dirTree.begin();
-	     iter != dirTree.end(); ++iter) {
+	for (sptr_list<DirectoryEntry>::iterator iter = dirTree->begin();
+	     iter != dirTree->end(); ++iter) {
 	
 		if (!first) {		// New line need ?
 			html.DrawChar(pad, '\n');
@@ -393,20 +424,7 @@ void	HyperTreeDraw::Draw(HyperDocument &html, WINDOW *pad)
 		}
 	}
 
-	if (curCol != 0) {		// Not end with new line
-		html.DrawChar(pad, '\n');
-		NewLineUpdateRowCol();	// One more line needed
-	}
-
-	if (! pad) {
-//ofstream ofs("xx", ios::app);
-//if (!pad)
-//ofs << htmlRow << ' ' << htmlCol << ' ' << '\n';
-		html.DrawSetSize(htmlRow, htmlCol);
-	}
-	else {
-		;			// Nothing to do
-	}
+	DrawEnd(html, pad);
 }
 
 /*************************************************************************
@@ -790,6 +808,9 @@ void	ExtendTree(sptr<DirectoryEntry> &d, const string &str)
 	}
 }
 
+// change - when true, check honor_cfg if change is required
+// honor_cfg - when true, don't modify tree if directory is in the list of SkipDir
+
 FindDirInfo *RecursiveFindDir(sptr<DirectoryEntry> &d, const string &current_dir, 
 			      const string &str, bool honor_cfg, bool change)
 {
@@ -889,15 +910,15 @@ FindDirInfo *RecursiveFindDir(sptr<DirectoryEntry> &d, const string &current_dir
 		return 0;
 }
 
-FindDirInfo *FindDir(const string &str, bool honor_cfg, bool change_top, 
-		     bool change_sub)
+FindDirInfo *FindDir(sptr_list<DirectoryEntry> *tree, const string &str,
+		     bool honor_cfg, bool change_top, bool change_sub)
 {
 	if (str.size() == 0)
 		return 0;
 						// Look for top-level directories
 
-	for (sptr_list<DirectoryEntry>::iterator iter = dirTree.begin();
-	     iter != dirTree.end(); ++iter) {
+	for (sptr_list<DirectoryEntry>::iterator iter = tree->begin();
+	     iter != tree->end(); ++iter) {
 	
 		if ((*iter)->IsDir()) {		// Make sure it's not a
 						// symbolic link
@@ -950,10 +971,10 @@ FindDirInfo *FindDir(const string &str, bool honor_cfg, bool change_top,
 
 		sptr<DirectoryEntry> d(new DirectoryEntry(str));
 		d->isSkip = 2;		// Mark as [*]
-		dirTree.push_back(d);	// Add our own top-level entry
+		tree->push_back(d);	// Add our own top-level entry
 
 		if (kcdConfig.cfgSortTree)
-			dirTree.sort();
+			tree->sort();
 
 		return new FindDirInfo(d, str);
 	}
@@ -961,167 +982,18 @@ FindDirInfo *FindDir(const string &str, bool honor_cfg, bool change_top,
 		return 0;
 }
 
-FindDirInfo *FindDir(const string &str, bool honor_cfg, bool change)
+FindDirInfo *FindDir(sptr_list<DirectoryEntry> *tree, const string &str,
+		     bool honor_cfg, bool change)
 {
-	return FindDir(str, honor_cfg, change, change);
+	return FindDir(tree, str, honor_cfg, change, change);
 }
 
 /*************************************************************************
-	Change directory
+	Screen setup
 *************************************************************************/
 
-void	GetBookmarks(list<MatchInfo> &match_list, const string &linktext);
-
-void	DirListCD(list<MatchInfo> &match_list, const string &init_pos,
-		  const string &str, size_t adjust)
+void FullScreenMode(HyperDraw *drawObj, const string &hyperInitPos)
 {
-	list<MatchInfo>::iterator iter;
-	list<MatchInfo>::iterator current;
-	for (iter = match_list.begin();
-	     iter != match_list.end(); ++iter) {
-		if ((*iter).is_curdir || (*iter).name == init_pos) {
-			current = iter;
-			break;
-		}
-	}
-	if (iter == match_list.end()) {
-						// getcwd fails
-		iter = match_list.begin();	// Arbitrary pick the first
-						// one
-	}
-	else {
-		iter = current;
-		next_loop(match_list, iter);	// Start from the next one
-	}
-
-						// Loop until we find a
-						// directory that actually
-						// exists
-	while (k_access((*iter).name, F_OK)) {
-		cout << flush;			// Avoid out-of-order display
-		gtout(cerr, _("%$: skipping %$"
-			      " - directory no longer exist\n"))
-		     << progName << (*iter).name;
-
-		next_loop(match_list, iter);
-		if (iter == current) {
-						// Can reach here
-			throw ErrorGenericFile(_("cannot find directory "
-						 "containing the string %$"),
-					       str);
-		}
-	}
-
-	FILE	*file = k_fopen(dirFile, "wb");
-	if (file == NULL) {			// Cannot create or truncate
-						// ~/.kcd.newdir
-		throw ErrorGenericFile(_("cannot create file %$"),
-				       dirFile);
-	}
-	
-						// Output desired dir
-	k_fputs((*iter).name, file);
-	fclose(file);
-
-	if (match_list.size() > adjust+1)	// More than one matched dir
-		cout << _("change to ") << (*iter).name << '\n';
-}
-
-void	CD(const string &linktext, bool entire_tree)
-{
-	LoadDirFile(1);
-
-	HyperDraw *drawObj = 0;
-	list<MatchInfo>	match_list;			// Must match lifetime
-							// of drawObj!
-
-	if (saveCwd.size())				// Current directory is available
-		FindDir(saveCwd, false);
-
-	string	hyperInitPos;
-	string	hyperFindLink;
-	
-	GenerateHTMLStrings();
-
-	if (linktext.size()) {				// kcd DIR
-
-		ImportBookmarks("");
-
-		if (entire_tree)			// Ignore bookmarks
-							// We add current
-							// directory into the mix
-							// to aid cycling through
-							// all match directory
-							// in the command line
-			FindMatchDir(match_list, linktext, true);
-
-		else {
-			GetBookmarks(match_list, linktext);
-			if (match_list.size()) {
-				if (match_list.size() > 1 && saveCwd.size()) {
-					list<MatchInfo>::iterator iter;
-					for (iter = match_list.begin();
-					     iter != match_list.end(); ++iter) {
-						if ((*iter).name == saveCwd)
-							break;
-					}
-					if (iter == match_list.end()) {
-							// Add current directory to aid jumping
-						FindDirInfo *f = FindDir(saveCwd, true, false);
-						match_list.push_front(MatchInfo(saveCwd, f->dir_ptr, true));
-					}
-				}
-			}
-			else {
-				FindMatchDir(match_list, linktext, true);
-			}
-		}
-
-		size_t	adjust = 0;			// In case getcwd fails
-		for (list<MatchInfo>::iterator iter = match_list.begin();
-		     iter != match_list.end(); ++iter) {
-			if ((*iter).is_curdir) {
-				adjust = 1;
-				break;
-			}
-		}
-							// +1 because of current
-							// directory in match_list
-		if (match_list.size() > static_cast<size_t>(kcdConfig.cfgShowListThreshold)
-					+adjust) {
-
-							// Show whole list
-
-							// Current directory is not
-							// need here.  Remove it.
-			match_list.remove_if(MatchInfoIsCurDir());
-			drawObj = new HyperListDraw(match_list);
-			
-			hyperInitPos = "";
-			hyperFindLink = "";
-			
-		}
-		else {					// Jump immediately
-			DirListCD(match_list, saveCwd, linktext, adjust);
-			return;
-		}
-	}
-	else {						// Browse dir tree
-		drawObj = new HyperTreeDraw();
-
-		hyperInitPos = saveCwd;
-		hyperFindLink = "";
-	}
-
-#ifdef DUMP_HTML
-	{
-		Buffer	buffer;
-		int handle = open("/home/lerdsuwa/devel/kcd/debug", O_RDWR|O_CREAT, 0700);
-		write(handle, buffer.GetPtr(), strlen(buffer.GetPtr()));
-		close(handle);
-	}
-#endif
-
 	HyperDocument		*html = new HyperDocument(drawObj);
 
 	{
@@ -1184,6 +1056,318 @@ void	CD(const string &linktext, bool entire_tree)
 	}
 }
 
+/*************************************************************************
+	Display tree functions
+*************************************************************************/
+
+void AddDisplayTree(const string &root, sptr_list<DirectoryEntry> *tree)
+{
+	string root_abs;			// Convert relative to absolute
+						// directory name
+	if (root[0] == '/' || root[0] == '~')
+		root_abs = ExpandDirectory(root, false);
+	else {
+		root_abs = saveCwd;
+		root_abs += '/';
+		root_abs += root;
+		root_abs = ExpandDirectory(root_abs, false);
+	}
+
+						// Allocate from heap since
+						// its lifetime is longer than
+						// this function
+	DirectoryEntry *entry = new DirectoryEntry(root_abs);
+	FindDirInfo *find = FindDir(&dirTree, root_abs, false, false);
+
+	if (find)
+		entry->subDir = find->dir_ptr->subDir;
+	else
+		entry->isSkip = 2;		// Not in file
+
+	tree->push_back(entry);
+}
+
+HyperDraw *GetDisplayTree(const string &root)
+{
+							// Allocate from heap since
+							// its lifetime is longer than
+							// this function
+	sptr_list<DirectoryEntry> *tree = new sptr_list<DirectoryEntry>;
+
+	if (root.size()) {
+		AddDisplayTree(root, tree);
+							// Add current directory after
+							// adding the entry above
+		if (saveCwd.size())			// Current directory is available
+			FindDir(tree, saveCwd, false);
+	}
+	else if (saveCwd.size()) {
+							// Allocate from heap since
+							// its lifetime is longer than
+							// this function
+		DirectoryEntry *entry = new DirectoryEntry(saveCwd);
+		FindDirInfo *find = FindDir(&dirTree, saveCwd, false, false);
+		if (find)
+			entry->subDir = find->dir_ptr->subDir;
+		else
+			entry->isSkip = 2;		// Not in file
+		tree->push_back(entry);
+	}
+	else
+		throw ErrorGenericCommandLine(_("cannot determine current directory"));
+
+	HyperDraw *drawObj;
+	if (tree->size()) {
+		RecursiveResolveSymLink(tree, *tree, string(""));
+		drawObj = new HyperTreeDraw(tree);
+	}
+	else						// Display entire tree
+		drawObj = new HyperTreeDraw(&dirTree);
+	return drawObj;
+}
+
+void	DisplayTree(const string &root, bool rescan)
+{
+	string str = root;
+	if (str.size() == 0) {
+		if (saveCwd.size())
+			str = saveCwd;
+		else
+			throw ErrorGenericCommandLine(_("cannot determine current directory"));
+	}
+
+	FindDirInfo *find = FindDir(&dirTree, str, false, false);
+	if (!find)
+		rescan = true;
+
+	if (rescan)
+		ScanDirAndDisplay(str, false);
+	GenerateHTMLStrings();
+	HyperDraw *drawObj = GetDisplayTree(str);
+	FullScreenMode(drawObj, "");
+}
+
+void	DisplayFullTree(bool rescan)
+{
+	if (rescan)
+		ScanDir(false);
+	GenerateHTMLStrings();
+	HyperDraw *drawObj = new HyperTreeDraw(&dirTree);
+	FullScreenMode(drawObj, "");
+}
+
+/*************************************************************************
+	Change directory
+*************************************************************************/
+
+void	GetBookmarks(list<MatchInfo> &match_list, const string &linktext);
+
+// FIXME: init_pos and adjust look redundant
+
+void	DirListCD(list<MatchInfo> &match_list, const string &init_pos,
+		  const string &str, size_t adjust, size_t match_no)
+{
+	list<MatchInfo>::iterator iter;
+
+	if (match_no) {
+							// Current directory is not
+							// need here.  Remove it.
+		match_list.remove_if(MatchInfoIsCurDir());
+		adjust = 0;
+
+		iter = match_list.begin();
+							// match_no starts at 1
+		for (size_t i = 1; i < match_no; ++i, ++iter)
+			;
+	}
+	else {
+		list<MatchInfo>::iterator current;
+
+		for (iter = match_list.begin();
+		     iter != match_list.end(); ++iter) {
+			if ((*iter).is_curdir || (*iter).name == init_pos) {
+				current = iter;
+				break;
+			}
+		}
+		if (iter == match_list.end()) {
+							// getcwd fails
+
+							// This checks every entry
+							// in the list
+
+			iter = match_list.begin();	// Arbitrary pick the first
+							// one
+			current = iter;			// Set terminate condition
+							// for the while loop below
+		}
+		else {
+							// This checks every entry
+							// except the current dir
+
+			iter = current;
+			next_loop(match_list, iter);	// Start from the next one
+		}
+
+							// Loop until we find a
+							// directory that actually
+							// exists
+		while (k_access((*iter).name, F_OK)) {
+			cout << flush;			// Avoid out-of-order display
+			gtout(cerr, _("%$: skipping %$"
+				      " - directory no longer exist\n"))
+			     << progName << (*iter).name;
+
+			next_loop(match_list, iter);
+			if (iter == current) {
+							// Can reach here when we
+							// have matches but all
+							// no longer exist
+				if (!(*current).is_curdir) {
+					cout << _("no directory change\n");
+					return;
+				}
+				else
+					throw ErrorGenericFile(_("cannot find directory "
+								 "containing the string %$"),
+							       str);
+			}
+		}
+	}
+
+	if ((*iter).is_curdir || (*iter).name == init_pos) {
+		cout << _("no directory change\n");
+		return;
+	}
+
+	FILE	*file = k_fopen(dirFile, "wb");
+	if (file == NULL) {			// Cannot create or truncate
+						// ~/.kcd.newdir
+		throw ErrorGenericFile(_("cannot create file %$"),
+				       dirFile);
+	}
+	
+							// Output desired dir
+	k_fputs((*iter).name, file);
+	fclose(file);
+
+	if (match_list.size() > adjust+1)	// More than one matched dir
+		cout << _("change to ") << (*iter).name << '\n';
+}
+
+void	CD(const string &linktext, bool entire_tree, size_t match_no)
+{
+	LoadDirFile(true);
+
+	HyperDraw *drawObj = 0;
+	list<MatchInfo>	match_list;			// Must match lifetime
+							// of drawObj!
+
+	if (saveCwd.size())				// Current directory is available
+		FindDir(&dirTree, saveCwd, false);
+
+	string	hyperInitPos;
+	
+	GenerateHTMLStrings();
+
+	if (linktext.size()) {				// kcd DIR
+
+		ImportBookmarks("");
+
+		if (entire_tree)			// Ignore bookmarks
+							// We add current
+							// directory into the mix
+							// to aid cycling through
+							// all match directory
+							// in the command line
+			FindMatchDir(match_list, linktext, true);
+
+		else {
+			GetBookmarks(match_list, linktext);
+			if (match_list.size()) {
+				if (match_list.size() > 1 && saveCwd.size()) {
+					list<MatchInfo>::iterator iter;
+					for (iter = match_list.begin();
+					     iter != match_list.end(); ++iter) {
+						if ((*iter).name == saveCwd)
+							break;
+					}
+					if (iter == match_list.end()) {
+							// Add current directory to aid jumping
+						FindDirInfo *f = FindDir(&dirTree, saveCwd, true, false);
+						match_list.push_front(MatchInfo(saveCwd, f->dir_ptr, true));
+					}
+				}
+			}
+			else {
+				FindMatchDir(match_list, linktext, true);
+			}
+		}
+
+		size_t	adjust = 0;			// In case getcwd fails
+		for (list<MatchInfo>::iterator iter = match_list.begin();
+		     iter != match_list.end(); ++iter) {
+			if ((*iter).is_curdir) {
+				adjust = 1;
+				break;
+			}
+		}
+							// +1 because of current
+							// directory in match_list
+		if ((match_list.size() > static_cast<size_t>(kcdConfig.cfgShowListThreshold)
+					 +adjust
+		     && match_no == 0)
+		    || match_no+adjust > match_list.size()) {
+
+							// Show whole list
+
+							// Current directory is not
+							// need here.  Remove it.
+			match_list.remove_if(MatchInfoIsCurDir());
+			drawObj = new HyperListDraw(match_list);
+			
+			hyperInitPos = "";
+			
+		}
+		else {					// Jump immediately
+			DirListCD(match_list, saveCwd, linktext, adjust, match_no);
+			return;
+		}
+	}
+	else {						// Browse dir tree
+		if (kcdConfig.cfgDefaultTree->size()) {
+							// Allocate from heap since
+							// its lifetime is longer than
+							// this function
+			sptr_list<DirectoryEntry> *tree = new sptr_list<DirectoryEntry>;
+
+			for (DirList::iterator iter = kcdConfig.cfgDefaultTree->begin();
+			     iter != kcdConfig.cfgDefaultTree->end(); ++iter) {
+				AddDisplayTree((*iter)->dir, tree);
+			}
+							// Add current directory after
+							// adding the entry above
+			if (saveCwd.size())		// Current directory is available
+				FindDir(tree, saveCwd, false);
+			drawObj = new HyperTreeDraw(tree);
+		}
+		else
+			drawObj = new HyperTreeDraw(&dirTree);
+		hyperInitPos = saveCwd;
+	}
+
+#ifdef DUMP_HTML
+	{
+		Buffer	buffer;
+		int handle = open("/home/lerdsuwa/devel/kcd/debug", O_RDWR|O_CREAT, 0700);
+		write(handle, buffer.GetPtr(), strlen(buffer.GetPtr()));
+		close(handle);
+	}
+#endif
+
+	FullScreenMode(drawObj, hyperInitPos);
+}
+
 /*************************************************************************
 	Bookmark helper functions
 *************************************************************************/
@@ -1194,7 +1378,7 @@ void	AddBookmark(const string &str, bool verify = true)
 {
 	string s = ExpandDirectory(str, false);
 	if (verify) {
-		FindDirInfo *f = FindDir(s, true, false);
+		FindDirInfo *f = FindDir(&dirTree, s, true, false);
 		if (f) {
 							// Prevent duplicate entries
 			if (find(bookmark_list.begin(), bookmark_list.end(), s)
@@ -1221,7 +1405,7 @@ void	RemoveBookmark(const string &str, bool verify = true)
 {
 	string s = ExpandDirectory(str, false);
 	if (verify) {
-		FindDirInfo *f = FindDir(s, true, false);
+		FindDirInfo *f = FindDir(&dirTree, s, true, false);
 		if (!f) {
 			cout << flush;			// Avoid out-of-order display
 			gtout(cerr, _("%$: cannot find %$ in saved directory tree\n"
@@ -1249,14 +1433,14 @@ void	GetBookmarks(list<MatchInfo> &match_list, const string &linktext)
 				link_pos = iter->find(linktext);
 
 			if (link_pos != string::npos) {
-				FindDirInfo *f = FindDir(*iter, true, false);
+				FindDirInfo *f = FindDir(&dirTree, *iter, true, false);
 				if (f)
 					match_list.push_back(MatchInfo(*iter, f->dir_ptr, false));
 				delete f;
 			}
 		}
 		else {
-			FindDirInfo *f = FindDir(*iter, true, false);
+			FindDirInfo *f = FindDir(&dirTree, *iter, true, false);
 			if (f)
 				match_list.push_back(MatchInfo(*iter, f->dir_ptr, false));
 			delete f;
@@ -1300,9 +1484,8 @@ void	ImportBookmarks(const string &filename)
 		s = bookmarkFile.c_str();
 
 	ifstream ifs(s);
-	if (!ifs) {
-		throw ErrorGenericFile(_("cannot read file %$"), s);
-	}
+	if (!ifs)		// Don't throw exception here
+		return;
 
 	for ( ; ; ) {
 		string	buffer;
@@ -1327,7 +1510,7 @@ void	ExportBookmarks(const string &filename)
 
 void	ShowBookmarks(const string &linktext)
 {
-	LoadDirFile(1);
+	LoadDirFile(true);
 	ImportBookmarks("");
 
 	list<MatchInfo>	match_list;
@@ -1344,74 +1527,12 @@ void	ShowBookmarks(const string &linktext)
 
 	HyperDraw *drawObj = new HyperListDraw(match_list);
 			
-	string	hyperInitPos = "";
-	string	hyperFindLink = "";
-			
-	HyperDocument		*html = new HyperDocument(drawObj);
-
-	{
-						// Display
-		NCurses::Init();
-
-		try {
-
-			if (COLS < 50 || LINES < 10) {
-				throw ErrorScreenTooSmall();
-			}
-			else {
-				init_entity_table();
-
-				khGeometryManager	geoMan(modeHVScroll);
-				khScreenManager		scrnMan(geoMan);
-
-				khStatusWindowWithFind	findBar(scrnMan, idStatWindow, NULL);
-				khURLWindowWithFind	urlBar(scrnMan, idURLWindow);
-				khHScrollBar		hscroll(scrnMan, idHScrollBar);
-				khVScrollBar		vscroll(scrnMan, idVScrollBar);
-				khScrollBox		cursorRest(scrnMan, idScrollBox);
-	
-				urlBar.SetTitle(" ");		// Empty title
-				scrnMan.SetCursor(&cursorRest);
-				scrnMan.RequestUpdateAndRestCursor();
-
-							// Use pre-computed 
-							// document size
-				khHyperWindowWithFind	hyper(scrnMan, idHyperWindow,
-							      *html, findBar, urlBar,
-							      hscroll, vscroll, hyperInitPos,
-							      1, htmlRow, htmlCol);
-
-				findBar.SetFindWindow(&hyper);
-				hscroll.SetWin(&hyper);	// Handle scroll through mouse
-				vscroll.SetWin(&hyper);
-				
-							// Set cfgSpaceSelect flag
-				khStatusWindowWithFind::spaceSelect = kcdConfig.cfgSpaceSelect;
-
-							// Send all keyboard input
-							// to hyper
-				scrnMan.SetFocus(&hyper);
-			
-							// Paint screen
-				scrnMan.RequestUpdateAndRestCursor();
-				hyper.KeyboardLoop();
-			}
-		}
-		catch (...) {
-			move(LINES-1, 0);
-			printf("\n\n");		// Avoid printing error
-						// message on top of drawn
-						// screen
-			NCurses::End();
-			throw;
-		}
-		NCurses::End();
-	}
+	FullScreenMode(drawObj, "");
 }
 
 void	AddBookmarks(int argc, char *argv[], int argcBegin)
 {
-	LoadDirFile(1);
+	LoadDirFile(true);
 	ImportBookmarks("");
 
 	if (argcBegin == argc) {
@@ -1454,7 +1575,7 @@ void	AddBookmarks(int argc, char *argv[], int argcBegin)
 
 void	RemoveBookmarks(int argc, char *argv[], int argcBegin)
 {
-	LoadDirFile(1);
+	LoadDirFile(true);
 	ImportBookmarks("");
 
 	if (argcBegin == argc) {
