@@ -1055,8 +1055,9 @@ Anchor	HyperWindow::ProcessCall(Anchor * /*p*/)
 #ifdef NCURSES_MOUSE_VERSION
 void	HyperWindow::ProcessMouse(MEVENT &event)
 {
-			// Only accepts mouse button 1 click & double click
-	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED)))
+			// Only accepts mouse button 1
+	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED
+			      | BUTTON1_TRIPLE_CLICKED | BUTTON1_RELEASED)))
 		return;
 
 	iterType saveIter = curAnchorIter;
@@ -1580,7 +1581,7 @@ void	HyperWindow::ProcessKeyScrollUpLines(size_t lines)
 			do {
 				--curAnchorIter;
 
-				if ((*curAnchorIter)->rowFrom <= (*saveIter)->rowFrom-lines) {
+				if ((*curAnchorIter)->rowFrom <= (*saveIter)->rowFrom-static_cast<int>(lines)) {
 					padRow -= lines;
 					if (padRow < 0)
 						padRow = 0;
@@ -1655,7 +1656,7 @@ void	HyperWindow::ProcessKeyScrollDownLines(size_t lines)
 			do {
 				++curAnchorIter;
 
-				if ((*curAnchorIter)->rowFrom >= (*saveIter)->rowFrom+lines) {
+				if ((*curAnchorIter)->rowFrom >= (*saveIter)->rowFrom+static_cast<int>(lines)) {
 					padRow += lines;
 					if (padRow+GetRow() > GetDocRow())
 						padRow = GetDocRow()-GetRow();
@@ -1999,7 +2000,7 @@ void	HyperWindow::ProcessKey(int ch)
 		}
 		else if (ch == 'E'-'A'+1) {	// ^E
 			if (viCount) {
-				if (viCount > curRow) {
+				if (viCount > static_cast<size_t>(curRow)) {
 					ProcessKeyScrollDownLines(viCount-curRow);
 					viCount = curRow;
 				}
@@ -2012,7 +2013,7 @@ void	HyperWindow::ProcessKey(int ch)
 		}
 		else if (ch == 'Y'-'A'+1) {	// ^Y
 			if (viCount) {
-				if (viCount > GetRow()-1-curRow) {
+				if (viCount > static_cast<size_t>(GetRow()-1-curRow)) {
 					ProcessKeyScrollUpLines(viCount-(GetRow()-1-curRow));
 					viCount = GetRow()-1-curRow;
 				}
@@ -2060,13 +2061,13 @@ void	HyperWindow::ProcessKey(int ch)
 			emacsFoundAlt = !emacsFoundAlt;
 			processAlt = true;
 		}
-		else if (ch == 'A'-'A'+1)		// ^A
+		else if (ch == 'A'-'A'+1)		// C-a
 			ProcessKeyBeginLine();
-		else if (ch == 'E'-'A'+1)		// ^E
+		else if (ch == 'E'-'A'+1)		// C-e
 			ProcessKeyEndLine();
-		else if (ch == 'B'-'A'+1 || ch == 'b' && emacsFoundAlt)	// ^B, M-b
+		else if (ch == 'B'-'A'+1 || ch == 'b' && emacsFoundAlt)	// C-b, M-b
 			ProcessKeyPrev();
-		else if (ch == 'F'-'A'+1 || ch == 'f' && emacsFoundAlt)	// ^F, M-f
+		else if (ch == 'F'-'A'+1 || ch == 'f' && emacsFoundAlt)	// C-f, M-f
 			ProcessKeyNext();
 		else if (ch == 'P'-'A'+1)		// C-p
 			ProcessKeyUp();
@@ -2225,7 +2226,7 @@ void	khHyperWindowWithFind::SelectText(const string & /*text*/)
 
 void	khHyperWindowWithFind::FindProcessKey(int ch)
 {
-	if (ch == KEY_F(10) || ch == KEY_F(9))
+	if (ch == KEY_F(10) || ch == KEY_F(9) || ch == 'C'-'A'+1)
 		HyperWindow::ProcessKey(ch);
 }
 
