@@ -83,80 +83,10 @@ void	HandleChdirError(ScanLog &scan_log, const string &dir, int e)
 
 int	dirUpdated = 0;			// Equals 1 if recan in this session
 
-/*************************************************************************
-	Expand every symbolic link to real directory names
-*************************************************************************/
-
-void	ResolveSymLink(sptr<DirectoryEntry> &d, const string &current_dir)
-{
-	int	ret;
-	
-	if (k_access(current_dir, F_OK))
-						// Shouldn't come here
-		d->isLinkDestSkip = 3;		// Not found
-	else if (k_access(current_dir, X_OK)) {
-		d->isLinkDestSkip = 0;
-		d->isLinkDestUnreadable = 1;	// Cannot change to
-						// this dir
-	}
-	else if (k_access(current_dir, R_OK)) {
-		d->isLinkDestSkip = 0;
-		d->isLinkDestUnreadable = 2;	// Cannot read dir
-	}
-	else {
-		d->isLinkDestUnreadable = 0;	// Access OK
-
-		ret = k_chdir(current_dir);
-		if (ret == 0) {
-					// Return empty string if unreadable
-					// otherwise it's the current working 
-					// dir with no symbolic link involved
-			string	linked_dir = k_getcwd();
-			if (!linked_dir.size()) {
-				d->isLinkDestSkip = 3;
-				return;
-			}
-			d->UpdateLinkDest(linked_dir);
-
-			FindDirInfo *dir_info = FindDir(linked_dir, false, false);
-			if (dir_info)
-				d->isLinkDestSkip = 0;
-			else
-				d->isLinkDestSkip = 1;
-			delete dir_info;
-		}
-		else {				// Shouldn't come here
-			d->isLinkDestSkip = 3;
-		}
-	}
-}
-
-void	RecursiveResolveSymLink(sptr_list<DirectoryEntry> &tree, const string &current_dir)
-{
-	for (sptr_list<DirectoryEntry>::iterator iter = tree.begin();
-	     iter != tree.end(); ++iter) {
-
-		string new_dir = current_dir;
-		new_dir += (*iter)->GetNameStr();
-
-		if ((*iter)->IsSymLink()) {
-			ResolveSymLink(*iter, new_dir);
-		}
-		else {
-						// Append trailing slash
-			if (new_dir[new_dir.size()-1] != '/')
-				new_dir += '/';
-
-						// Recursion...
-			RecursiveResolveSymLink((*iter)->subDir, new_dir);
-		}
-	}
-}
-
 void	ExpandSymLink(ScanLog &scan_log)
 {
 	scan_log.PrintWork(_("Resolving symbolic links"));
-	RecursiveResolveSymLink(dirTree, string(""));
+	RecursiveResolveSymLink(&dirTree, dirTree, string(""));
 }
 
 /*************************************************************************
@@ -266,9 +196,7 @@ void	FullScanDir(ScanLog &scan_log)
 	time(&t1);
 	SetScanTime(t1);
 
-	LoadAllConfig(0);
-	kcdConfig.SetScanMode(SCAN_MODE_FULL, forceQuiet);
-	scan_log.SetQuiet(kcdConfig.cfgQuiet);
+	scan_log.SetQuiet(kcdConfig.cfgQuietFull);
 
 	dirTree.clear();
 
@@ -531,11 +459,9 @@ void	SmartScanDir(ScanLog &scan_log)
 	time_t t1, t2;			// Get current time
 	time(&t1);
 
-	LoadAllConfig(0);
-	kcdConfig.SetScanMode(SCAN_MODE_SMART, forceQuiet);
-	scan_log.SetQuiet(kcdConfig.cfgQuiet);
+	scan_log.SetQuiet(kcdConfig.cfgQuietSmart);
 
-	LoadDirFile(1);		// Load saved tree for timestamp info
+	LoadDirFile(true);	// Load saved tree for timestamp info
 
 	SetScanTime(t1);	// New scan time
 
@@ -692,7 +618,7 @@ void	DoPartialScanDir(ScanLog &scan_log, const string &str_, bool full_scan)
 					      str_);
 	}
 
-	FindDirInfo *dir_info = FindDir(str, true, false, true);
+	FindDirInfo *dir_info = FindDir(&dirTree, str, true, false, true);
 	if (!dir_info) {
 		throw ErrorGenericCommandLine(_("%$ is either a special directory, in `SkipDir\' or not in `StartDir\'"),
 					      str_);
@@ -726,11 +652,9 @@ void	PartialScanDir(ScanLog &scan_log, const vector<string> &str_, bool full_sca
 	time(&t1);
 					// Do not update scan time here
 
-	LoadAllConfig(0);
-	kcdConfig.SetScanMode(SCAN_MODE_PARTIAL, forceQuiet);
-	scan_log.SetQuiet(kcdConfig.cfgQuiet);
+	scan_log.SetQuiet(kcdConfig.cfgQuietPartial);
 
-	LoadDirFile(1);
+	LoadDirFile(true);
 	for (size_t i = 0; i < str_.size(); ++i) {
 		DoPartialScanDir(scan_log, str_[i], full_scan);
 		if (i != str_.size()-1 && saveCwd.size())
@@ -774,3 +698,27 @@ void	PartialScanDir(const vector<string> &str_, bool full_scan)
 	CommandLineScanLog	scan_log;
 	PartialScanDir(scan_log, str_, full_scan);
 }
+
+void	ScanDirAndDisplay(const string &str_, bool full_scan)
+{
+	CommandLineScanLog	scan_log;
+	scan_log.SetQuiet(kcdConfig.cfgQuietPartial);
+
+	FindDirInfo *find = FindDir(&dirTree, str_, false, false);
+	if (find) {
+		DoPartialScanDir(scan_log, str_, full_scan);
+		ExpandSymLink(scan_log);
+		WriteDirFile();			// Update saved tree too
+	}
+	else {
+		dirTree.clear();
+						// Allow scanning inside
+						// skipped directory
+		delete kcdConfig.cfgSkipDir;
+		kcdConfig.cfgSkipDir = new DirList;
+
+		FullScanFromDir(scan_log, str_);
+		ExpandSymLink(scan_log);
+	}
+}
+
