@@ -1,6 +1,6 @@
 /*
 	scandir.h	Scan Directory Functions Header
-	Copyright (c) 2000,2001 Kriang Lerdsuwanakij
+	Copyright (c) 2000,2001,2003 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -32,14 +32,14 @@ USING_NAMESPACE_STD;
 
 class ScanLog {
 	protected:
-		int	quiet;
+		bool	quiet;
 	public:
 		virtual void PrintDirectory(const string &str) = 0;
 		virtual void PrintWork(const string &str) = 0;
 		virtual void PrintTime(long secdiff, const string &mode) = 0;
 		virtual void PrintStartDirNotFound(const string &str) = 0;
 		virtual void PrintChdirError(const string &dir, const string &str) = 0;
-		void SetQuiet(int quiet_) { quiet = quiet_; }
+		void SetQuiet(bool quiet_) { quiet = quiet_; }
 };
 
 class CommandLineScanLog : public ScanLog {
@@ -51,11 +51,10 @@ class CommandLineScanLog : public ScanLog {
 		void PrintChdirError(const string &dir, const string &str);
 };
 
-extern int	forceQuiet;
-
 void	FullScanDir();
 void	SmartScanDir();
 void	ScanDir(bool full_scan);
 void	PartialScanDir(const vector<string> &str_, bool full_scan);
+void	ScanDirAndDisplay(const string &str_, bool full_scan);
 
 #endif	/* __K_SCANDIR_H */
