@@ -246,8 +246,9 @@ void	khHScrollBar::ProcessMouse(MEVENT &event)
 	if (!win)	// Window hiden
 		return;
 		
-			// Only accepts mouse button 1 click & double click
-	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED)))
+			// Only accepts mouse button 1
+	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED
+			      | BUTTON1_TRIPLE_CLICKED | BUTTON1_RELEASED)))
 		return;
 
 	if (controlledWin) {
@@ -295,8 +296,9 @@ void	khVScrollBar::ProcessMouse(MEVENT &event)
 	if (!win)	// Window hiden
 		return;
 		
-			// Only accepts mouse button 1 click & double click
-	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED)))
+			// Only accepts mouse button 1
+	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED
+			      | BUTTON1_TRIPLE_CLICKED | BUTTON1_RELEASED)))
 		return;
 
 	if (controlledWin) {
