@@ -60,12 +60,11 @@ void	DrawStatusBarHelper(WINDOW *win, int num_col, int hide_size, const string &
 
 void	StatusWindowBase::NextStatus()
 {
-	statusNo = (statusNo+1)%maxStatus;
+	statusNo = (statusNo+1)%MaxStatus();
 }
 
-StatusWindowBase::StatusWindowBase(NCScreenManager &scrnMan_, int id_, int _maxStatus) : 
-			NCWindowBase(scrnMan_, id_), statusNo(0), 
-			maxStatus(_maxStatus)
+StatusWindowBase::StatusWindowBase(NCScreenManager &scrnMan_, int id_) : 
+			NCWindowBase(scrnMan_, id_), statusNo(0)
 {
 }
 
@@ -148,7 +147,7 @@ void	khStatusWindow::DrawStatusBar(int num)
 }
 
 khStatusWindow::khStatusWindow(NCScreenManager &scrnMan_, int id_) :
-			StatusWindowBase(scrnMan_, id_, 1),
+			StatusWindowBase(scrnMan_, id_),
 			title("")
 {
 	Init();
@@ -158,13 +157,6 @@ khStatusWindow::khStatusWindow(NCScreenManager &scrnMan_, int id_) :
 	kcd/khyper URL window
 *************************************************************************/
 
-char	*khURLWindow::statKey1 = N_("Keys (1):  Arrows,PgUp,PgDn,Home,End=Move cursor"
-			"  Enter,Space=Select");
-char	*khURLWindow::statKey2 = N_("Keys (2):  ^R,F8=Repaint screen  F9=Switch display"
-			"  ^C,F10=Quit");
-char	*khURLWindow::statKey3 = N_("Keys (3):  Keypad Center=Center highlight"
-			"  `,\',`.\'=Pan left/right");
-
 void	khURLWindow::Init()
 {
 	NCWindowBase::Init();
@@ -215,8 +207,9 @@ void	khURLWindow::NextStatus()
 #ifdef NCURSES_MOUSE_VERSION
 void	khURLWindow::ProcessMouse(MEVENT &event)
 {
-			// Only accepts mouse button 1 click & double click
-	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED)))
+			// Only accepts mouse button 1
+	if (!(event.bstate & (BUTTON1_CLICKED | BUTTON1_DOUBLE_CLICKED
+			      | BUTTON1_TRIPLE_CLICKED | BUTTON1_RELEASED)))
 		return;
 
 	NextStatus();
@@ -267,12 +260,39 @@ void	khURLWindow::DrawStatusBar(int num)
 }
 
 khURLWindow::khURLWindow(NCScreenManager &scrnMan_, int id_) :
-			StatusWindowBase(scrnMan_, id_, DISP_NUMDISPLAY),
+			StatusWindowBase(scrnMan_, id_),
 			title("")
 {
 	switch_disp = _("F9=Switch display");
 	switch_disp_width = GetStringWidth(switch_disp);
 
+	switch (kcdConfig.cfgKey) {
+		case keyBindingDefault:
+			statKey1 = _("Keys (1):  Arrows,PgUp,PgDn,Home,End=Move cursor"
+				     "  Enter,Space=Select");
+			statKey2 = _("Keys (2):  ^R,F8=Repaint screen  F9=Switch display"
+				     "  ^C,F10=Quit");
+			statKey3 = _("Keys (3):  Keypad Center=Center highlight"
+				     "  `,\',`.\'=Pan left/right");
+			break;
+		case keyBindingVi:
+			statKey1 = _("Keys (1v):  Arrows,PgUp,PgDn,Home,End=Move cursor"
+				     "  Enter,Space=Select");
+			statKey2 = _("Keys (2v):  ^L,F8=Repaint screen  F9=Switch display"
+				     "  ^C,F10=Quit");
+			statKey3 = _("Keys (3v):  Keypad Center=Center highlight"
+				     "  `,\',`.\'=Pan left/right");
+			break;
+		case keyBindingEmacs:
+			statKey1 = _("Keys (1e):  Arrows,PgUp,PgDn,Home,End=Move cursor"
+				     "  Enter,Space=Select");
+			statKey2 = _("Keys (2e):  F8=Repaint screen  F9=Switch display"
+				     "  C-c,F10=Quit");
+			statKey3 = _("Keys (3e):  Keypad Center=Center highlight"
+				     "  `,\',`.\'=Pan left/right");
+			break;
+	}
+
 	Init();
 }
 
@@ -280,14 +300,6 @@ khURLWindow::khURLWindow(NCScreenManager &scrnMan_, int id_) :
 	kcd/khyper URL window with find key help
 *************************************************************************/
 
-char	*khURLWindowWithFind::statKey4WithFind = N_("Keys (4):  A-Z,a-z,0-9=Enter find mode");
-
-char	*khURLWindowWithFind::statKeyFind = N_("Keys in find mode:  Up/Dn=Prev/next match"
-			"  TAB=Exit find  ENTER=Select");
-
-char	*khURLWindowWithFind::statKeyCtrlF = N_("^F:  8=Repaint screen  9=Switch display"
-			"  0=Quit");
-
 void	khURLWindowWithFind::ProcessCtrl(char /*c*/, bool s)
 {
 	wmove(win, 0, 0);
@@ -333,7 +345,29 @@ khURLWindowWithFind::khURLWindowWithFind(NCScreenManager &scrnMan_, int id_) :
 			khURLWindow(scrnMan_, id_)
 {
 	scrnMan_.SetCtrlWindow(this);
-	maxStatus = DISP_NUMDISPLAYFIND;
+
+	switch (kcdConfig.cfgKey) {
+		case keyBindingDefault:
+			statKey4WithFind = _("Keys (4):  A-Z,a-z,0-9=Enter find mode");
+			statKeyFind = _("Keys in find mode:  Up/Dn=Prev/next match"
+					"  TAB=Exit find  ENTER=Select");
+			statKeyCtrlF = _("^F:  8=Repaint screen  9=Switch display"
+					 "  0=Quit");
+			break;
+		case keyBindingVi:
+			statKey4WithFind = _("Keys (4v):  /,?=Enter find mode");
+			statKeyFind = _("Keys in find mode:  TAB=Exit find  ENTER=Select");
+			statKeyCtrlF = _("^F:  8=Repaint screen  9=Switch display"
+					 "  0=Quit");
+			break;
+		case keyBindingEmacs:
+			statKey4WithFind = _("Keys (4e):  C-s,C-r=Enter find mode");
+			statKeyFind = _("Keys in find mode:  Up/Dn=Prev/next match"
+					"  TAB=Exit find  ENTER=Select");
+			statKeyCtrlF = _("C-f:  8=Repaint screen  9=Switch display"
+					 "  0=Quit");
+			break;
+	}
 }
 
 /*************************************************************************
